@@ -7,7 +7,7 @@ class EMToolsApplicationTest(IMP.test.ApplicationTestCase):
 
     def test_mol2pca(self):
         """Simple test of mol2pca application"""
-        p = self.run_python_application('mol2pca.py',
+        p = self.run_python_application('mol2pca',
                                         [self.get_input_file_name('mini.pdb'), 'mini.cmm'])
         out, err = p.communicate()
         sys.stderr.write(err)
@@ -21,7 +21,7 @@ class EMToolsApplicationTest(IMP.test.ApplicationTestCase):
 
     def test_map2pca(self):
         """Simple test of map2pca application"""
-        p = self.run_python_application('map2pca.py',
+        p = self.run_python_application('map2pca',
                                         [self.get_input_file_name(
                                             'mini.mrc'), '1.0',
                                          'mini.cmm'])
@@ -37,7 +37,7 @@ class EMToolsApplicationTest(IMP.test.ApplicationTestCase):
 
     def test_simulate_density(self):
         """Simple test of simulate_density_from_pdb application"""
-        p = self.run_python_application('simulate_density_from_pdb.py',
+        p = self.run_python_application('simulate_density_from_pdb',
                                         [self.get_input_file_name(
                                             'mini.pdb'), 'mini.mrc',
                                          '1.0', '4.0'])
@@ -48,7 +48,7 @@ class EMToolsApplicationTest(IMP.test.ApplicationTestCase):
 
     def test_resample_density(self):
         """Simple test of resample_density application"""
-        p = self.run_python_application('resample_density.py',
+        p = self.run_python_application('resample_density',
                                         [self.get_input_file_name(
                                             'mini.mrc'), '1',
                                          'out.mrc'])
