@@ -1,7 +1,7 @@
 /**
  * \file EMFit \brief
  *
- * Copyright 2007-2013 IMP Inventors. All rights reserved.
+ * Copyright 2007-2014 IMP Inventors. All rights reserved.
  *
  */
 
@@ -18,43 +18,43 @@
 #include <IMP/kernel/Particle.h>
 
 class EMFit {
-public:
+ public:
   // Constructors
   // for fitting of docking solutions
   EMFit(std::string rec_file_name, std::string lig_file_name,
         std::string map_file_name, float resolution, float dist_thr,
         float volume_scale = 1.5);
   // for fitting of single structure
-  EMFit(std::string pdb_file_name, std::string map_file_name,
-        float resolution, float dist_thr, float volume_scale = 1.5);
+  EMFit(std::string pdb_file_name, std::string map_file_name, float resolution,
+        float dist_thr, float volume_scale = 1.5);
 
   // docking transformations
-  void runPCA(std::string trans_file, bool use_cc_score=false);
+  void runPCA(std::string trans_file, bool use_cc_score = false);
 
   // single structure
   void runPCA();
 
-  void output(std::string out_file_name, std::string out_pdb_file_name="");
+  void output(std::string out_file_name, std::string out_pdb_file_name = "");
 
-private:
+ private:
   float compute_volume(const IMP::kernel::Particles& particles);
   float estimate_density_threshold(float object_volume) const;
   void read_trans_file(const std::string file_name,
                        std::vector<IMP::algebra::Transformation3D>& transforms);
 
-  void read_pdb_atoms(IMP::kernel::Model *model, const std::string file_name,
+  void read_pdb_atoms(IMP::kernel::Model* model, const std::string file_name,
                       IMP::kernel::Particles& particles);
 
   void compute_zscores();
 
-private:
+ private:
   IMP::base::PointerMember<IMP::kernel::Model> model_;
   IMP::kernel::Particles rec_particles_, lig_particles_;
   std::string rec_file_name_, lig_file_name_;
   IMP::base::PointerMember<IMP::em::DensityMap> map_;
   IMP::base::PointerMember<IMP::em::MapDistanceTransform> distance_transform_;
   IMP::base::PointerMember<IMP::em::EnvelopeScore> envelope_score_;
-  MapScorer *cc_score_;
+  MapScorer* cc_score_;
   float dist_thr_;
   float density_threshold_;
   std::vector<FitResult> fit_results_;
