@@ -8,6 +8,7 @@
 
 #include "lib/SOAPResult.h"
 #include "lib/soap_score.h"
+#include "lib/Normalization.h"
 #include "../lib/helpers.h"
 
 #include <IMP/kernel/Model.h>
@@ -65,22 +66,26 @@ int main(int argc, char** argv) {
   // input parsing
   std::string out_file_name;
   bool oriented_potentials = false;
-  std::string potentials_file;
+  bool normalize = false;
+  std::string potentials_file, receptor_potentials_file, ligand_potentials_file;
   po::options_description desc(
       "Usage: <pdb1> <pdb2> [trans_file] OR <filenames.txt>");
-  desc.add_options()(
-      "help",
-      "Option 1: compute the SOAP score of the interface between pdb1 and pdb2 \
+  desc.add_options()
+    ("help",
+     "Option 1: compute the SOAP score of the interface between pdb1 and pdb2 \
 for a set of transformations in the trans_file.\n Option 2: compute SOAP scores for \
-each pair of PDB file names in the input file filenames.txt.")(
-      "input-files", po::value<std::vector<std::string> >(), "input PDBs")(
-      "oriented_potentials,r",
-      "use orientation dependent potentials \
-(default = false). Please provide potentials file.")(
-      "potentials_file,f", po::value<std::string>(&potentials_file),
-      "potentials file")("output_file,o", po::value<std::string>(&out_file_name)
-                                              ->default_value("soap_score.res"),
-                         "output file name, default name soap_score.res");
+each pair of PDB file names in the input file filenames.txt.")
+    ("input-files", po::value<std::vector<std::string> >(), "input PDBs")
+    ("oriented_potentials,r", "use orientation dependent potentials \
+(default = false). Please provide potentials file.")
+    ("potentials_file,f", po::value<std::string>(&potentials_file), "potentials file")
+    ("receptor_potentials_file", po::value<std::string>(&receptor_potentials_file), "receptor potentials file")
+    ("ligand_potentials_file", po::value<std::string>(&ligand_potentials_file), "ligand potentials file")
+    ("normalize,n", "Normalize by residue type (default = false).")
+    ("output_file,o",
+     po::value<std::string>(&out_file_name)->default_value("soap_score.res"),
+     "output file name, default name soap_score.res")
+    ;
 
   po::positional_options_description p;
   p.add("input-files", -1);
@@ -107,6 +112,8 @@ each pair of PDB file names in the input file filenames.txt.")(
                 << std::endl;
     }
   }
+  if (vm.count("normalize")) normalize = true;
+
 
   // init SOAP table
   float distance_threshold = 15.0;
@@ -131,14 +138,19 @@ each pair of PDB file names in the input file filenames.txt.")(
   std::vector<SOAPResult> results;                // scored complexes
   std::ofstream out_file(out_file_name.c_str());  // open output file
 
+  Normalization *normalization;
+  if (normalize) {
+    normalization = new Normalization(IMP::score_functor::get_data_path("residue_norm.lib"));
+  }
+
   // Option 1: score pairs of PDBs fom filenames.txt
   std::vector<std::pair<std::string, std::string> > file_names;
   if (files.size() == 1) {
     read_input_file(files[0], file_names);
 
     for (unsigned int i = 0; i < file_names.size(); i++) {
-      read_pdb(file_names[i].first, model, pis1);
-      read_pdb(file_names[i].second, model, pis2);
+      IMP::atom::Hierarchy mhd1 = read_pdb(file_names[i].first, model, pis1);
+      IMP::atom::Hierarchy mhd2 = read_pdb(file_names[i].second, model, pis2);
 
       // score
       double score = 0.0;
@@ -148,15 +160,85 @@ each pair of PDB file names in the input file filenames.txt.")(
         score = soap_score(soap_distance_score, model, pis1, pis2,
                            distance_threshold);
       }
+
       // save
       results.push_back(SOAPResult(i + 1, score, false, 0.0, score));
 
+      // meanwhile we only normalize ligand, eg. peptide
+      if (normalize) {
+        IMP::kernel::ParticleIndexes res_pis =
+          IMP::get_as<IMP::kernel::ParticleIndexes>(get_by_type(mhd2, IMP::atom::RESIDUE_TYPE));
+        std::map<IMP::atom::ResidueType, int> residue_content;
+        for (unsigned int k = 0; k<res_pis.size(); k++) {
+          IMP::atom::ResidueType rt =
+            IMP::atom::Residue(model, res_pis[k]).get_residue_type();
+          if (residue_content.find(rt) == residue_content.end())
+            residue_content[rt] = 0;
+          residue_content[rt]++;
+        }
+
+        double nscore = (normalization->get_normalization_score(residue_content))/2.0;
+        results[i].set_score(results[i].get_score() + nscore);
+        results[i].set_normalization_score(nscore);
+      }
+
       // clean up
       for (unsigned int k = 0; k < pis1.size(); k++)
         model->remove_particle(pis1[k]);
       for (unsigned int k = 0; k < pis2.size(); k++)
         model->remove_particle(pis2[k]);
     }
+
+    if (oriented_potentials) delete soap_oriented_score;
+
+    // score receptor only
+    if (receptor_potentials_file.length() > 0) {
+      // load table
+      IMP::score_functor::OrientedSoap *receptor_soap_oriented_score =
+        new IMP::score_functor::OrientedSoap(receptor_potentials_file);
+      std::cerr << receptor_soap_oriented_score->get_distance_threshold() << std::endl;
+
+      // calculate score
+      for (unsigned int i = 0; i < file_names.size(); i++) {
+        IMP::atom::Hierarchy mhd1 = read_pdb(file_names[i].first, model, pis1);
+        IMP::ParticlesTemp bonds = add_bonds(mhd1);
+        IMP_NEW(IMP::atom::StereochemistryPairFilter, pair_filter, ());
+        pair_filter->set_bonds(bonds);
+        double rscore = oriented_soap_score(receptor_soap_oriented_score, model, pis1, pair_filter);
+        results[i].set_score(results[i].get_score() + rscore);
+        results[i].set_sas_score(rscore);
+        // clean up
+        //delete pair_filter;
+        for (unsigned int k = 0; k < pis1.size(); k++)
+          model->remove_particle(pis1[k]);
+      }
+      delete receptor_soap_oriented_score;
+    }
+
+    // score ligand only
+    if (ligand_potentials_file.length() > 0) {
+      // load table
+      IMP::score_functor::OrientedSoap *ligand_soap_oriented_score =
+        new IMP::score_functor::OrientedSoap(ligand_potentials_file);
+      std::cerr << ligand_soap_oriented_score->get_distance_threshold() << std::endl;
+
+      // calculate score
+       for (unsigned int i = 0; i < file_names.size(); i++) {
+         IMP::atom::Hierarchy mhd2 = read_pdb(file_names[i].second, model, pis2);
+         IMP::ParticlesTemp bonds = add_bonds(mhd2);
+         IMP_NEW(IMP::atom::StereochemistryPairFilter, pair_filter, ());
+         pair_filter->set_bonds(bonds);
+         double lscore = oriented_soap_score(ligand_soap_oriented_score, model, pis2, pair_filter);
+         results[i].set_score(results[i].get_score() + lscore);
+         results[i].set_sas_score(lscore);
+         // clean up
+         //delete pair_filter;
+         for (unsigned int k = 0; k < pis2.size(); k++)
+           model->remove_particle(pis2[k]);
+       }
+       delete ligand_soap_oriented_score;
+    }
+
     out_file << "filename (str) " << files[0] << std::endl;
 
   } else {
