@@ -17,9 +17,8 @@
 
 IMPALGEBRA_BEGIN_NAMESPACE
 
-/** Represent an ellispoid in 3D.
-    \geometry
-  */
+//! Represent an ellipsoid in 3D.
+/** \geometry */
 class IMPALGEBRAEXPORT Ellipsoid3D : public GeometricPrimitiveD<3> {
  public:
   Ellipsoid3D() {}
