@@ -26,15 +26,15 @@ IMPALGEBRA_BEGIN_NAMESPACE
 */
 
 //! Returns the vector product (cross product) of two vectors.
-/** See Vector3D
+/** \see Vector3D
  */
 inline Vector3D get_vector_product(const Vector3D &p1, const Vector3D &p2) {
   return Vector3D(p1[1] * p2[2] - p1[2] * p2[1], p1[2] * p2[0] - p1[0] * p2[2],
                   p1[0] * p2[1] - p1[1] * p2[0]);
 }
 //! Return a vector that is perpendicular to the given vector
-/** Or, if you are Israeli, it is a vertical vector.
-    See Vector3D
+/** \note This is occasionally refered to in the code as a "vertical" vector.
+    \see Vector3D
 */
 inline Vector3D get_orthogonal_vector(const Vector3D &v) {
   unsigned int maxi = 0;
@@ -51,7 +51,7 @@ inline Vector3D get_orthogonal_vector(const Vector3D &v) {
 }
 
 //! Returns the centroid of a set of vectors
-/** See Vector3D
+/** \see Vector3D
  */
 inline Vector3D get_centroid(const Vector3Ds &ps) {
   return std::accumulate(ps.begin(), ps.end(), get_zero_vector_d<3>()) /
