@@ -26,25 +26,25 @@ IMPALGEBRA_BEGIN_NAMESPACE
  */
 //! Write a set of 3D vectors to a file
 /** \see read_pts
-    See VectorD
+    \see VectorD
 */
 IMPALGEBRAEXPORT void write_pts(const Vector3Ds &vs, base::TextOutput out);
 
 //! Read a set of 3D vectors from a file
 /** \see write_pts
-    See VectorD
+    \see VectorD
 */
 IMPALGEBRAEXPORT Vector3Ds read_pts(base::TextInput input);
 
 //! Write a set of 3d spheres to a file
 /** \see read_pts
-    See SphereD
+    \see SphereD
 */
 IMPALGEBRAEXPORT void write_spheres(const Sphere3Ds &vs, base::TextOutput out);
 
 //! Read a set of 3d spheres from a file
 /** \see write_pts
-    See SphereD
+    \see SphereD
 */
 IMPALGEBRAEXPORT Sphere3Ds read_spheres(base::TextInput input);
 
