@@ -15,14 +15,14 @@
 
 IMPATOM_BEGIN_NAMESPACE
 
-/** Return the atoms comprising the phi dihedral.
-    If all atoms cannot be found, an empty list is returned.
-    See Residue */
+//! Return the atoms comprising the phi dihedral.
+/** If all atoms cannot be found, an empty list is returned.
+    \see Residue */
 IMPATOMEXPORT Atoms get_phi_dihedral_atoms(Residue rd);
 
-/** Return the atoms comprising the psi dihedral.
-    If all atoms cannot be found, an empty list is returned.
-    See Residue */
+//! Return the atoms comprising the psi dihedral.
+/** If all atoms cannot be found, an empty list is returned.
+    \see Residue */
 IMPATOMEXPORT Atoms get_psi_dihedral_atoms(Residue rd);
 
 IMPATOM_END_NAMESPACE
