@@ -76,7 +76,7 @@ IMPATOMEXPORT double get_rmsd(
     const core::XYZs& s0, const core::XYZs& s1,
     const IMP::algebra::Transformation3D& tr_for_second);
 
-//! Calculate the root mean square deviation between two sets of 3D points.
+//! Calculate distance the root mean square deviation between two sets of 3D points.
 /**
    \note the function assumes correspondence between the two sets of
    points and does not need rigid alignment. Note that it is different from
@@ -110,6 +110,45 @@ inline double get_drmsd(const Vector3DsOrXYZs0& m0,
   return std::sqrt(drmsd / npairs);
 }
 
+
+//! Calculate the distance root mean square deviation between two sets of 3D points
+//! with a distance threshold
+/**
+   \note the function assumes correspondence between the two sets of
+   points and does not need rigid alignment. Note that it is different from
+   get_drmsd().
+
+   \genericgeometry
+ */
+template <class Vector3DsOrXYZs0, class Vector3DsOrXYZs1>
+inline double get_drmsd_Q(const Vector3DsOrXYZs0& m0,
+                          const Vector3DsOrXYZs1& m1, double threshold) {
+  using algebra::get_vector_geometry;
+  IMP_USAGE_CHECK(m0.size() == m1.size(), "The input sets of XYZ points "
+                                              << "should be of the same size");
+  double drmsd = 0.0;
+
+  int npairs = 0;
+  for (unsigned i = 0; i < m0.size() - 1; ++i) {
+    algebra::Vector3D v0i = get_vector_geometry(m0[i]);
+    algebra::Vector3D v1i = get_vector_geometry(m1[i]);
+
+    for (unsigned j = i + 1; j < m0.size(); ++j) {
+      algebra::Vector3D v0j = get_vector_geometry(m0[j]);
+      algebra::Vector3D v1j = get_vector_geometry(m1[j]);
+      
+      double dist0 = algebra::get_distance(v0i, v0j);
+      double dist1 = algebra::get_distance(v1i, v1j);
+      if (dist0<=threshold || dist1<=threshold){
+        drmsd += (dist0 - dist1) * (dist0 - dist1);
+        npairs++;
+      }
+    }
+  }
+  return std::sqrt(drmsd / npairs);
+}
+
+
 //! Computes the native overlap between two sets of 3D points
 /**
   \param[in] m1 first set
@@ -124,7 +163,7 @@ template <class Vector3DsOrXYZs0, class Vector3DsOrXYZs1>
 inline double get_native_overlap(const Vector3DsOrXYZs0& m1,
                                  const Vector3DsOrXYZs1& m2, double threshold) {
   IMP_USAGE_CHECK(m1.size() == m2.size(),
-                  "native_verlap: The input sets of XYZ points "
+                  "native_overlap: The input sets of XYZ points "
                       << "should be of the same size");
   unsigned int distances = 0;
   for (unsigned int i = 0; i < m1.size(); i++) {
@@ -146,7 +185,7 @@ inline double get_native_overlap(const Vector3DsOrXYZs0& m1,
 template <class Vector3DsOrXYZs0, class Vector3DsOrXYZs1>
 inline double get_drms(const Vector3DsOrXYZs0& m1, const Vector3DsOrXYZs1& m2) {
   IMP_USAGE_CHECK(m1.size() == m2.size(),
-                  "native_verlap: The input sets of XYZ points "
+                  "native_overlap: The input sets of XYZ points "
                       << "should be of the same size");
 
   unsigned int n = m1.size();
