@@ -1,6 +1,6 @@
 /**
  *  \file IMP/atom/python_only.h
- *  \brief functionality only availble in python.
+ *  \brief Functionality only available in Python.
  *
  *  Copyright 2007-2014 IMP Inventors. All rights reserved.
  *
@@ -14,19 +14,21 @@
 IMPATOM_BEGIN_NAMESPACE
 
 /** \name Python Only
-    The following functions are only availale in Python as the
+    The following functions are only available in Python as the
     equivalent C++ functionality is provided via template
     functions or in other ways that don't directly map to
-    python.
+    Python.
     @{
 */
 #ifdef IMP_DOXYGEN
-/** Print out the molecular hierarchy. Equivalent to
+
+//! Print out the molecular hierarchy.
+/** Equivalent to
 \code
 IMP::core::show(h);
 \endcode
 */
-void show_molecular_hiearchy(Hierarchy h);
+void show_molecular_hierarchy(Hierarchy h);
 #endif
 /** @} */
 
