@@ -463,7 +463,7 @@ ResidueType CHARMMParameters::parse_residue_line(const String &line,
   if (ResidueType::get_key_exists(curr_residue)) {
     return ResidueType(curr_residue);
   } else {
-    // assume charmm is correct
+    // assume CHARMM is correct
     return ResidueType(ResidueType::add_key(curr_residue));
   }
 }
@@ -677,7 +677,7 @@ void CHARMMParameters::read_parameter_file(base::TextInput input_file) {
     }
   }
   if (force_field_2_vdW_.size() == 0) {
-    IMP_FAILURE("NONBONDED params not found in Charmm parameter file");
+    IMP_FAILURE("NONBONDED params not found in CHARMM parameter file");
   }
 }
 
@@ -697,38 +697,51 @@ String CHARMMParameters::get_force_field_atom_type(Atom atom) const {
   }
 }
 
+namespace {
+  class TopologyInserter {
+    CHARMMTopology *topology_;
+    const CHARMMParameters *params_;
+    base::WarningContext warn_context_;
+  public:
+    TopologyInserter(CHARMMTopology *topology, const CHARMMParameters *params,
+                     base::WarningContext warn_context)
+               : topology_(topology), params_(params),
+                 warn_context_(warn_context) {}
+  
+    void operator()(Hierarchies residues) {
+      IMP_NEW(CHARMMSegmentTopology, segment, ());
+      for (Hierarchies::iterator resit = residues.begin();
+           resit != residues.end(); ++resit) {
+        ResidueType restyp = Residue(*resit).get_residue_type();
+        try {
+          IMP_NEW(CHARMMResidueTopology, residue,
+                  (params_->get_residue_topology(restyp)));
+          segment->add_residue(residue);
+        }
+        catch (base::ValueException) {
+          // If residue type is unknown, add empty topology for this residue
+          IMP_WARN_ONCE(
+              restyp.get_string(),
+              "Residue type "
+                  << restyp
+                  << " was not found in "
+                     "topology library; using empty topology for this residue",
+              warn_context_);
+          IMP_NEW(CHARMMResidueTopology, residue, (restyp));
+          segment->add_residue(residue);
+        }
+      }
+      topology_->add_segment(segment);
+    }
+  };
+}
+
 CHARMMTopology *CHARMMParameters::create_topology(Hierarchy hierarchy) const {
   IMP_OBJECT_LOG;
   IMP_NEW(CHARMMTopology, topology, (this));
 
-  Hierarchies chains = get_by_type(hierarchy, CHAIN_TYPE);
-
-  for (Hierarchies::iterator chainit = chains.begin(); chainit != chains.end();
-       ++chainit) {
-    IMP_NEW(CHARMMSegmentTopology, segment, ());
-    Hierarchies residues = get_by_type(*chainit, RESIDUE_TYPE);
-    for (Hierarchies::iterator resit = residues.begin();
-         resit != residues.end(); ++resit) {
-      ResidueType restyp = Residue(*resit).get_residue_type();
-      try {
-        IMP_NEW(CHARMMResidueTopology, residue, (get_residue_topology(restyp)));
-        segment->add_residue(residue);
-      }
-      catch (base::ValueException) {
-        // If residue type is unknown, add empty topology for this residue
-        IMP_WARN_ONCE(
-            restyp.get_string(),
-            "Residue type "
-                << restyp
-                << " was not found in "
-                   "topology library; using empty topology for this residue",
-            warn_context_);
-        IMP_NEW(CHARMMResidueTopology, residue, (restyp));
-        segment->add_residue(residue);
-      }
-    }
-    topology->add_segment(segment);
-  }
+  TopologyInserter ins(topology, this, warn_context_);
+  internal::visit_connected_chains(hierarchy, ins);
   // keep clang happy
   bool dumped = false;
   IMP_IF_LOG(VERBOSE) {
