@@ -112,12 +112,12 @@ void ForceFieldParameters::add_bonds(Residue rd1, Residue rd2) const {
 
   Bonded b1, b2;
   if (Bonded::get_is_setup(p1))
-    b1 = Bonded::decorate_particle(p1);
+    b1 = Bonded(p1);
   else
     b1 = Bonded::setup_particle(p1);
 
   if (Bonded::get_is_setup(p2))
-    b2 = Bonded::decorate_particle(p2);
+    b2 = Bonded(p2);
   else
     b2 = Bonded::setup_particle(p2);
 
@@ -148,12 +148,12 @@ void ForceFieldParameters::add_bonds(Residue rd) const {
 
     Bonded b1, b2;
     if (Bonded::get_is_setup(p1))
-      b1 = Bonded::decorate_particle(p1);
+      b1 = Bonded(p1);
     else
       b1 = Bonded::setup_particle(p1);
 
     if (Bonded::get_is_setup(p2))
-      b2 = Bonded::decorate_particle(p2);
+      b2 = Bonded(p2);
     else
       b2 = Bonded::setup_particle(p2);
 
