@@ -14,8 +14,11 @@ kcal2mod = 4.1868e-4
 # Mass of Carbon-12 (g/mol)
 cmass = 12.011
 
+
 class XTransRestraint(IMP.kernel.Restraint):
+
     """Attempt to move the whole system along the x axis"""
+
     def __init__(self, m, strength):
         IMP.kernel.Restraint.__init__(self, m, "XTransRestraint %1%")
         self.strength = strength
@@ -31,27 +34,34 @@ class XTransRestraint(IMP.kernel.Restraint):
                 p.add_to_derivative(ykey, 0.0, accum)
                 p.add_to_derivative(zkey, 0.0, accum)
         return e
+
     def get_version_info(self):
         return IMP.VersionInfo("Daniel Russel", "0.5")
+
     def do_show(self, fh):
         fh.write("Test restraint")
+
     def do_get_inputs(self):
         return [x for x in self.get_model().get_particles()]
 
 
 class WriteTrajState(IMP.OptimizerState):
+
     """Write system coordinates (trajectory) into a Python list"""
+
     def __init__(self, m, traj):
         IMP.OptimizerState.__init__(self, m, "WriteTrajState%1%")
         self.traj = traj
+
     def do_update(self, call):
         model = self.get_optimizer().get_model()
         self.traj.append([(p.get_value(xkey), p.get_value(ykey),
-                           p.get_value(zkey), p.get_value(vxkey)) \
-                           for p in model.get_particles()])
+                           p.get_value(zkey), p.get_value(vxkey))
+                          for p in model.get_particles()])
 
 
 class Tests(IMP.test.TestCase):
+
     """Test molecular dynamics optimizer"""
 
     def setUp(self):
@@ -83,15 +93,15 @@ class Tests(IMP.test.TestCase):
                     self.assertAlmostEqual(coor[n][d], step[n][d], delta=1e-3,
                                            msg=msg % (coor[n][d], step[n][d],
                                                       num, n, d))
-                coor[n][0] += (newvx+vx)/2.0 * timestep
+                coor[n][0] += (newvx + vx) / 2.0 * timestep
             vx = newvx
 
     def _optimize_model(self, timestep):
         """Run a short MD optimization on the model."""
-        start = [[p.get_value(xkey), p.get_value(ykey), p.get_value(zkey)] \
+        start = [[p.get_value(xkey), p.get_value(ykey), p.get_value(zkey)]
                  for p in self.model.get_particles()]
         # Add starting (step 0) position to the trajectory, with zero velocity
-        traj = [[x+[0] for x in start]]
+        traj = [[x + [0] for x in start]]
         state = WriteTrajState(self.model, traj)
         self.md.add_optimizer_state(state)
         self.md.set_maximum_time_step(timestep)
@@ -120,9 +130,9 @@ class Tests(IMP.test.TestCase):
         # Strength is so high that velocity should max out at the cap
         for i in range(49):
             oldx = traj[i][0][0]
-            newx = traj[i+1][0][0]
+            newx = traj[i + 1][0][0]
             # Calculate velocity from change in position
-            self.assertAlmostEqual((oldx-newx) / timestep, 0.3, delta=1e-5)
+            self.assertAlmostEqual((oldx - newx) / timestep, 0.3, delta=1e-5)
 
     def test_non_xyz(self):
         """Should skip particles without xyz attributes"""
@@ -143,9 +153,9 @@ class Tests(IMP.test.TestCase):
         ekinetic = self.md.get_kinetic_energy()
         tkinetic = self.md.get_kinetic_temperature(ekinetic)
         self.assertAlmostEqual(tkinetic, desired,
-                     msg="Temperature %f does not match expected %f within %f" \
-                         % (tkinetic, desired, tolerance),
-                     delta=tolerance)
+                               msg="Temperature %f does not match expected %f within %f"
+                               % (tkinetic, desired, tolerance),
+                               delta=tolerance)
 
     def test_temperature(self):
         """Check temperature"""
@@ -179,8 +189,9 @@ class Tests(IMP.test.TestCase):
     def test_get_optimizer_states(self):
         """Test get_optimizer_states() method"""
         wrtraj = WriteTrajState(self.model, [])
-        scaler = IMP.atom.VelocityScalingOptimizerState(
-                             self.particles, 298.0, 10)
+        scaler = IMP.atom.VelocityScalingOptimizerState(self.model,
+                                                        self.particles, 298.0)
+        scaler.set_period(10)
         self.md.add_optimizer_state(wrtraj)
         self.md.add_optimizer_state(scaler)
         m = self.md.get_optimizer_states()
@@ -195,8 +206,9 @@ class Tests(IMP.test.TestCase):
                                                              -43.0, 65.0, 93.0))
             self.particles[-1].add_attribute(masskey, cmass, False)
         self.md.assign_velocities(100.0)
-        scaler = IMP.atom.VelocityScalingOptimizerState(
-                             self.particles, 298.0, 10)
+        scaler = IMP.atom.VelocityScalingOptimizerState(self.model,
+                                                        self.particles, 298.0)
+        scaler.set_period(10)
         self.md.add_optimizer_state(scaler)
         self.md.optimize(10)
         # Temperature should have been rescaled to 298.0 at some point:
