@@ -15,15 +15,15 @@
 
 IMPBASE_BEGIN_NAMESPACE
 #if IMP_HAS_CHECKS
-/** Return the names of all live objects, use this to check for memory
-    leaks.*/
+//! Return the names of all live objects.
+/** Use this to check for memory leaks. */
 IMPBASEEXPORT Strings get_live_object_names();
-/** Return the points to all live objects, use this to check for memory
-    leaks.*/
+
+//! Return pointers to all live objects.
+/** Use this to check for memory leaks. */
 IMPBASEEXPORT Objects get_live_objects();
 
-/** Set whether to complain about objects not being properly cleaned up.
- */
+//! Set whether to complain about objects not being properly cleaned up.
 IMPBASEEXPORT void set_show_leaked_objects(bool tf);
 #endif
 
