@@ -24,7 +24,7 @@
     @param Name the class name
     @param args the argument string (in parens) for the explicit constructor
                 and set()
-    @param Initialize code called from any constrcutor, including the default
+    @param Initialize code called from any constructor, including the default
     @param Set the code called from the explicit constructor or the set()
                function
     @param Reset the code called from the destructor, and in set before calling
