@@ -1,12 +1,12 @@
 /**
  *  \file exception.cpp   \brief Check handling.
  *
- *  Copyright 2007-2013 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2014 IMP Inventors. All rights reserved.
  *
  */
 
 #include "IMP/base/deprecation.h"
-#include "IMP/base/internal/static.h"
+#include "internal/static.h"
 #include "IMP/base/exception.h"
 #include "IMP/base/log_macros.h"
 
@@ -18,14 +18,14 @@ void handle_use_deprecated(std::string message) {
 #else
   if (false) {
 #endif
-    if (internal::print_deprecation_messages) {
+    if (internal::no_print_deprecation_messages) {
       if (internal::printed_deprecation_messages.find(message) ==
           internal::printed_deprecation_messages.end()) {
         IMP_WARN(message);
         internal::printed_deprecation_messages.insert(message);
       }
     }
-    // we only have a stacktrace if logging is on
+// we only have a stacktrace if logging is on
 #if IMP_HAS_LOG > IMP_SILENT
     if (internal::exceptions_on_deprecation) {
       throw UsageException(message.c_str());
@@ -35,7 +35,7 @@ void handle_use_deprecated(std::string message) {
 }
 
 void set_deprecation_warnings(bool tf) {
-  internal::print_deprecation_messages = tf;
+  internal::no_print_deprecation_messages = !tf;
 }
 
 void set_deprecation_exceptions(bool tf) {
