@@ -16,9 +16,9 @@
 IMPBENCHMARK_BEGIN_NAMESPACE
 
 /** One can use the
-    [GPerfTools](http://code.google.com/p/gperftools/)
-    the GPerfTools profiler} to profile code. On a mac, you should
-    use the Instruments program instead (part of the mac os developer tools).
+    [GPerfTools profiler](http://code.google.com/p/gperftools/)
+    to profile code. On a Mac, you should
+    use the Instruments program instead (part of the Mac OS X Developer Tools).
 */
 class IMPBENCHMARKEXPORT Profiler : public base::RAII {
   void start(std::string name);
