@@ -1,6 +1,6 @@
 /* Why would we copyright a test?
  */
-#include <IMP/base/map.h>
+#include <boost/unordered_map.hpp>
 #include <IMP/base/Vector.h>
 IMP_COMPILER_DISABLE_WARNINGS
 IMP_CLANG_PRAGMA(diagnostic ignored "-Wc++11-extensions")
@@ -15,10 +15,14 @@ IMP_CLANG_PRAGMA(diagnostic ignored "-Wc++11-extensions")
 #include <CGAL/Gmpq.h>
 IMP_COMPILER_ENABLE_WARNINGS
 int main(int, char * []) {
-  double pts[][3] = {{3.3874, 3.3577, 2.86547}, {4.20832, 3.04325, 3.05838},
-                     {3.63033, 2.62921, 2.50657}, {4.3492, 2.80494, 1.99437},
-                     {5.24092, 2.81322, 2.11588}, {6.00076, 3.29489, 2.1409},
-                     {5.53583, 3.6421, 1.45294}, {5.97231, 2.95352, 1.07171},
+  double pts[][3] = {{3.3874, 3.3577, 2.86547},
+                     {4.20832, 3.04325, 3.05838},
+                     {3.63033, 2.62921, 2.50657},
+                     {4.3492, 2.80494, 1.99437},
+                     {5.24092, 2.81322, 2.11588},
+                     {6.00076, 3.29489, 2.1409},
+                     {5.53583, 3.6421, 1.45294},
+                     {5.97231, 2.95352, 1.07171},
                      {5.29922, 3.54395, 0.980338},
                      {5.46575, 3.92853, 0.183865}};
   typedef CGAL::Exact_predicates_inexact_constructions_kernel IKernel;
