@@ -40,11 +40,11 @@ class IMPCOREEXPORT ClosePairsFinder : public kernel::ParticleInputs,
   ClosePairsFinder(std::string name);
   ~ClosePairsFinder();
 
-  /** \deprecated_at{2.1} use the index-based on instead. */
+  /** \deprecated_at{2.1} use the index-based one instead. */
   IMPCORE_DEPRECATED_METHOD_DECL(2.1)
   kernel::ParticlePairsTemp get_close_pairs(const kernel::ParticlesTemp &pc)
       const;
-  /** \deprecated_at{2.1} use the index-based on instead. */
+  /** \deprecated_at{2.1} use the index-based one instead. */
   IMPCORE_DEPRECATED_METHOD_DECL(2.1)
   kernel::ParticlePairsTemp get_close_pairs(
       const kernel::ParticlesTemp &pca, const kernel::ParticlesTemp &pcb) const;
@@ -81,9 +81,7 @@ class IMPCOREEXPORT ClosePairsFinder : public kernel::ParticleInputs,
   IMP_LIST(public, PairFilter, pair_filter, PairPredicate *, PairPredicates);
 /**@}*/
 #if !defined(SWIG) && !defined(IMP_DOXYGEN)
-  /** \brief Return a container which lists all particles which moved more
-      than threshold
-  */
+  //! Return a container of all particles which moved more than threshold
   virtual internal::MovedSingletonContainer *get_moved_singleton_container(
       SingletonContainer *in, double threshold) const;
 #endif
