@@ -20,6 +20,7 @@ IMPCORE_BEGIN_NAMESPACE
 IMP_FUNCTOR_DISTANCE_PAIR_SCORE(
     DistancePairScore, score_functor::UnaryFunctionEvaluate,
     (UnaryFunction *uf, std::string name = "DistancePairScore%1%"), (uf));
+IMP_OBJECTS(DistancePairScore, DistancePairScores);
 
 #ifndef IMP_DOXYGEN
 typedef score_functor::Shift<score_functor::Harmonic> HarmonicDistanceScore;
@@ -32,6 +33,8 @@ IMP_FUNCTOR_DISTANCE_PAIR_SCORE(
     HarmonicDistancePairScore, HarmonicDistanceScore,
     (double x0, double k, std::string name = "HarmonicDistancePairScore%1%"),
     (x0, score_functor::Harmonic(k)));
+IMP_OBJECTS(HarmonicDistancePairScore, HarmonicDistancePairScores);
+
 IMPCORE_END_NAMESPACE
 
 #endif /* IMPCORE_DISTANCE_PAIR_SCORE_H */
