@@ -2,7 +2,7 @@
  *  \file IMP/core/MinimumRestraint.h
  *  \brief Score based on the k minimum restraints.
  *
- *  Copyright 2007-2013 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2014 IMP Inventors. All rights reserved.
  *
  */
 
@@ -22,13 +22,9 @@ IMPCORE_BEGIN_NAMESPACE
  */
 class IMPCOREEXPORT MinimumRestraint : public kernel::Restraint {
   unsigned int k_;
-  void on_add(kernel::Restraint *r) const;
 
  public:
-  /** Score based on the num minimum restraints from rs. The restraints
-      must already be registered with the model (either by being added
-      to the model scoring function, upon constructior or having
-      kernel::Restraint::set_model() called on them.
+  /** Score based on the num minimum restraints from rs.
    */
   MinimumRestraint(unsigned int num,
                    const kernel::Restraints &rs = kernel::Restraints(),
@@ -44,9 +40,7 @@ class IMPCOREEXPORT MinimumRestraint : public kernel::Restraint {
   ;
 
   IMP_LIST_ACTION(public, Restraint, Restraints, restraint, restraints,
-                  kernel::Restraint *, kernel::Restraints, on_add(obj);
-                  , {}, {});
-  void set_model(kernel::Model *m);
+                  kernel::Restraint *, kernel::Restraints, , {}, {});
 };
 
 IMPCORE_END_NAMESPACE
