@@ -72,7 +72,7 @@ class IMPCOREEXPORT XYZR : public XYZ {
   void set_sphere(const algebra::Sphere3D &s) {
     get_model()->get_sphere(get_particle_index()) = s;
   }
-  /** Get the key for the radius. */
+  //! Get the key for the radius.
   static FloatKey get_radius_key() { return IMP::internal::xyzr_keys[3]; }
   void add_to_radius_derivative(double v, DerivativeAccumulator &d) {
     get_particle()->add_to_derivative(get_radius_key(), v, d);
@@ -82,8 +82,7 @@ class IMPCOREEXPORT XYZR : public XYZ {
 IMP_DECORATORS(XYZR, XYZRs, XYZs);
 
 //! Compute the sphere distance between a and b
-/** Compute the spere distance between a and b
-    See XYZR
+/** \see XYZR
  */
 inline double get_distance(XYZR a, XYZR b) {
   return IMP::algebra::get_distance(a.get_sphere(), b.get_sphere());
@@ -99,7 +98,7 @@ inline double get_distance(XYZR a, XYZR b) {
     \note This function produces tighter bounds if the \ref cgal "CGAL"
     library is available.
     \ingroup CGAL
-    See XYZR
+    \see XYZR
  */
 IMPCOREEXPORT void set_enclosing_sphere(XYZR b, const XYZs &v,
                                         double slack = 0);
@@ -110,7 +109,7 @@ IMPCOREEXPORT void set_enclosing_sphere(XYZR b, const XYZs &v,
     Any particle which does not have the attribute b.get_radius()
     is assumed to have a radius of 0.
 
-    See XYZR
+    \see XYZR
  */
 IMPCOREEXPORT void set_enclosing_radius(XYZR b, const XYZs &v);
 
@@ -119,7 +118,7 @@ IMPCOREEXPORT void set_enclosing_radius(XYZR b, const XYZs &v);
     Any particle which does not have the attribute b.get_radius()
     is assumed to have a radius of 0.
 
-    See XYZR
+    \see XYZR
  */
 IMPCOREEXPORT algebra::Sphere3D get_enclosing_sphere(const XYZs &v);
 
@@ -130,7 +129,7 @@ IMPCOREEXPORT algebra::Sphere3D get_enclosing_sphere(const XYZs &v);
     \param[in] radius The radius to give them.
     \param[in] box_side The particles have coordinates from -box_side
     to box_side.
-    See XYZR
+    \see XYZR
 
     The particles coordinates are optimized.
  */
