@@ -2,7 +2,7 @@
  *  \file MovedSingletonContainer.h
  *  \brief Keep track of the maximum change of a set of attributes.
  *
- *  Copyright 2007-2013 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2014 IMP Inventors. All rights reserved.
  */
 
 #ifndef IMPCORE_INTERNAL_MOVED_SINGLETON_CONTAINER_H
@@ -14,9 +14,11 @@
 #include <IMP/kernel/Particle.h>
 #include <IMP/SingletonContainer.h>
 #include <IMP/SingletonModifier.h>
-#include <IMP/kernel/internal/InternalDynamicListSingletonContainer.h>
+#include <IMP/kernel/internal/ListLikeContainer.h>
 #include <IMP/algebra/Sphere3D.h>
 #include <IMP/base/Pointer.h>
+#include <boost/unordered_set.hpp>
+#include <boost/unordered_map.hpp>
 #include "../XYZR.h"
 #include "../rigid_bodies.h"
 #include <IMP/kernel/internal/container_helpers.h>
@@ -25,28 +27,28 @@
 IMPCORE_BEGIN_INTERNAL_NAMESPACE
 
 class IMPCOREEXPORT MovedSingletonContainer
-    : public IMP::internal::ListLikeSingletonContainer {
+    : public kernel::internal::ListLikeContainer<kernel::SingletonContainer> {
  private:
   double threshold_;
   base::Pointer<SingletonContainer> pc_;
-  int pc_version_;
-  bool reset_all_;
-  bool reset_moved_;
+  std::size_t pc_version_;
+  base::PointerMember<ScoreState> score_state_;
   virtual kernel::ParticleIndexes get_all_possible_indexes() const IMP_OVERRIDE;
   virtual kernel::ModelObjectsTemp do_get_inputs() const IMP_OVERRIDE;
-  virtual void do_before_evaluate() IMP_OVERRIDE;
   virtual kernel::ParticleIndexes get_range_indexes() const IMP_OVERRIDE;
   IMP_OBJECT_METHODS(MovedSingletonContainer);
   virtual kernel::ParticleIndexes do_get_moved() = 0;
   virtual void do_reset_all() = 0;
   virtual void do_reset_moved() = 0;
   virtual kernel::ParticleIndexes do_initialize() = 0;
+  virtual kernel::ModelObjectsTemp get_extra_inputs() const = 0;
 
  public:
-  void do_after_evaluate(DerivativeAccumulator *);
+  kernel::ModelObjectsTemp get_score_state_inputs() const;
+  void do_score_state_before_evaluate();
+  void do_score_state_after_evaluate();
   void initialize();
   virtual void validate() const = 0;
-  //! Track the changes with the specified keys.
   MovedSingletonContainer(SingletonContainer *pc, double threshold,
                           std::string name);
 
@@ -70,11 +72,14 @@ class IMPCOREEXPORT MovedSingletonContainer
 class IMPCOREEXPORT XYZRMovedSingletonContainer
     : public MovedSingletonContainer {
   base::Vector<algebra::Sphere3D> backup_;
-  base::set<int> moved_;
+  boost::unordered_set<int> moved_;
   virtual kernel::ParticleIndexes do_get_moved();
   virtual void do_reset_all();
   virtual void do_reset_moved();
   virtual kernel::ParticleIndexes do_initialize();
+  kernel::ModelObjectsTemp get_extra_inputs() const {
+    return kernel::ModelObjectsTemp();
+  }
 
  public:
   virtual void validate() const;
@@ -86,8 +91,9 @@ class IMPCOREEXPORT RigidMovedSingletonContainer
     : public MovedSingletonContainer {
   base::Vector<std::pair<algebra::Sphere3D, algebra::Rotation3D> > backup_;
   kernel::ParticleIndexes bodies_;
-  base::set<int> moved_;
-  IMP::base::map<kernel::ParticleIndex, kernel::ParticleIndexes> rbs_members_;
+  boost::unordered_set<int> moved_;
+  boost::unordered_map<kernel::ParticleIndex, kernel::ParticleIndexes>
+      rbs_members_;
   virtual kernel::ParticleIndexes do_get_moved();
   virtual void do_reset_all();
   virtual void do_reset_moved();
@@ -98,30 +104,8 @@ class IMPCOREEXPORT RigidMovedSingletonContainer
                       std::pair<algebra::Sphere3D, algebra::Rotation3D> s,
                       double d) const;
 
-  double get_distance_estimate(unsigned int i) const {
-    core::XYZR xyz(get_model(), bodies_[i]);
-    if (!core::RigidBody::get_is_setup(get_model(), bodies_[i])) {
-      return (xyz.get_coordinates() - backup_[i].first.get_center())
-          .get_magnitude();
-    } else {
-      core::RigidBody rb(get_model(), bodies_[i]);
-      double dr = std::abs(xyz.get_radius() - backup_[i].first.get_radius());
-      double dx = (xyz.get_coordinates() - backup_[i].first.get_center())
-                      .get_magnitude();
-      algebra::Rotation3D nrot =
-          rb.get_reference_frame().get_transformation_to().get_rotation();
-      algebra::Rotation3D diffrot = backup_[i].second.get_inverse() * nrot;
-      double angle = algebra::get_axis_and_angle(diffrot).second;
-      double drot =
-          std::abs(angle * xyz.get_radius());  // over estimate, but easy
-      double ret = dr + dx + drot;
-      IMP_IF_CHECK(USAGE_AND_INTERNAL) {
-        check_estimate(core::RigidBody(get_model(), bodies_[i]), backup_[i],
-                       ret);
-      }
-      return ret;
-    }
-  }
+  double get_distance_estimate(unsigned int i) const;
+
   std::pair<algebra::Sphere3D, algebra::Rotation3D> get_data(
       kernel::ParticleIndex p) const {
     if (!core::RigidBody::get_is_setup(get_model(), p)) {
@@ -135,7 +119,7 @@ class IMPCOREEXPORT RigidMovedSingletonContainer
                                 .get_rotation());
     }
   }
-  kernel::ParticlesTemp get_input_particles() const;
+  kernel::ModelObjectsTemp get_extra_inputs() const;
 
  public:
   //! Track the changes with the specified keys.
