@@ -1,7 +1,7 @@
 /**
  *  \file ClosedCubicSpline.cpp  \brief Closed cubic spline function.
  *
- *  Copyright 2007-2013 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2014 IMP Inventors. All rights reserved.
  *
  */
 
@@ -80,8 +80,8 @@ double ClosedCubicSpline::evaluate(double feature) const {
              (spacing_ * spacing_) / 6.;
 }
 
-DerivativePair ClosedCubicSpline::evaluate_with_derivative(
-    double feature) const {
+DerivativePair ClosedCubicSpline::evaluate_with_derivative(double feature)
+    const {
   size_t lowbin = static_cast<size_t>((feature - minrange_) / spacing_);
   size_t highbin = lowbin + 1;
   size_t npoints = values_.size();
