@@ -4,7 +4,7 @@
  *  Restrict max distance between at least one pair of particles of any
  *  two distinct types.
  *
- *  Copyright 2007-2013 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2014 IMP Inventors. All rights reserved.
  *
  */
 
@@ -13,9 +13,11 @@
 #include <IMP/kernel/Model.h>
 #include <IMP/kernel/Particle.h>
 #include <IMP/base/log.h>
-#include <IMP/PairScore.h>
+#include <IMP/kernel/PairScore.h>
+#include <IMP/kernel/SingletonContainer.h>
+#include <IMP/kernel/SingletonModifier.h>
+#include <IMP/kernel/internal/StaticListContainer.h>
 #include <IMP/core/PairRestraint.h>
-#include <IMP/kernel/internal/InternalListSingletonContainer.h>
 
 #include <climits>
 
@@ -28,22 +30,26 @@
 
 IMPCORE_BEGIN_NAMESPACE
 
-ConnectivityRestraint::ConnectivityRestraint(PairScore *ps,
-                                             SingletonContainer *sc)
+ConnectivityRestraint::ConnectivityRestraint(kernel::PairScore *ps,
+                                             SingletonContainerAdaptor sc)
     : kernel::Restraint(sc->get_model(), "ConnectivityRestraint %1%"), ps_(ps) {
+  sc.set_name_if_default("ConnectivityRestraintInput%1%");
   sc_ = sc;
 }
 
-ConnectivityRestraint::ConnectivityRestraint(PairScore *ps)
-    : kernel::Restraint("ConnectivityRestraint %1%"), ps_(ps) {
+ConnectivityRestraint::ConnectivityRestraint(kernel::Model *m,
+                                             kernel::PairScore *ps)
+    : kernel::Restraint(m, "ConnectivityRestraint %1%"), ps_(ps) {
   IMPCORE_DEPRECATED_METHOD_DEF(2.1, "Use constructor that takes container.");
 }
 
 namespace {
-IMP::internal::InternalListSingletonContainer *get_list(
+kernel::internal::StaticListContainer<kernel::SingletonContainer> *get_list(
     SingletonContainer *sc) {
-  IMP::internal::InternalListSingletonContainer *ret =
-      dynamic_cast<IMP::internal::InternalListSingletonContainer *>(sc);
+  kernel::internal::StaticListContainer<kernel::SingletonContainer> *ret =
+      dynamic_cast<
+          kernel::internal::StaticListContainer<kernel::SingletonContainer> *>(
+          sc);
   if (!ret) {
     IMP_THROW("Can only use the set and add methods when no container"
                   << " was passed on construction of ConnectivityRestraint.",
@@ -55,7 +61,7 @@ IMP::internal::InternalListSingletonContainer *get_list(
 
 void ConnectivityRestraint::set_particles(const kernel::ParticlesTemp &ps) {
   if (!sc_ && !ps.empty()) {
-    sc_ = new IMP::internal::InternalListSingletonContainer(
+    sc_ = new kernel::internal::StaticListContainer<kernel::SingletonContainer>(
         ps[0]->get_model(), "connectivity list");
   }
   get_list(sc_)->set(IMP::internal::get_index(ps));
@@ -63,7 +69,7 @@ void ConnectivityRestraint::set_particles(const kernel::ParticlesTemp &ps) {
 
 void ConnectivityRestraint::add_particles(const kernel::ParticlesTemp &ps) {
   if (!sc_ && !ps.empty()) {
-    sc_ = new IMP::internal::InternalListSingletonContainer(
+    sc_ = new kernel::internal::StaticListContainer<kernel::SingletonContainer>(
         ps[0]->get_model(), "connectivity list");
   }
   get_list(sc_)->add(IMP::internal::get_index(ps));
@@ -71,7 +77,7 @@ void ConnectivityRestraint::add_particles(const kernel::ParticlesTemp &ps) {
 
 void ConnectivityRestraint::add_particle(kernel::Particle *ps) {
   if (!sc_) {
-    sc_ = new IMP::internal::InternalListSingletonContainer(
+    sc_ = new kernel::internal::StaticListContainer<kernel::SingletonContainer>(
         ps->get_model(), "connectivity list");
   }
   get_list(sc_)->add(IMP::internal::get_index(ps));
@@ -138,8 +144,8 @@ ParticleIndexPairs get_edges(const SingletonContainer *a, PairScore *ps) {
 }
 }
 
-double ConnectivityRestraint::unprotected_evaluate(
-    DerivativeAccumulator *accum) const {
+double ConnectivityRestraint::unprotected_evaluate(DerivativeAccumulator *accum)
+    const {
   IMP_CHECK_OBJECT(ps_.get());
   IMP_OBJECT_LOG;
   base::Vector<Edge> mst;
