@@ -16,9 +16,12 @@
 IMPCORE_BEGIN_NAMESPACE
 
 DistanceRestraint::DistanceRestraint(UnaryFunction* score_func,
-                                     kernel::Particle* p1, kernel::Particle* p2)
+                                     kernel::Particle* p1, kernel::Particle* p2,
+                                     std::string name
+)
     : IMP::internal::TupleRestraint<DistancePairScore>(
           new DistancePairScore(score_func), p1->get_model(),
-          kernel::ParticleIndexPair(p1->get_index(), p2->get_index())) {}
+          kernel::ParticleIndexPair( p1->get_index(), p2->get_index() ),
+          name) {}
 
 IMPCORE_END_NAMESPACE
