@@ -1,12 +1,13 @@
 /**
  *  \file XYZ.cpp   \brief Simple xyz decorator.
  *
- *  Copyright 2007-2013 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2014 IMP Inventors. All rights reserved.
  *
  */
 
 #include <IMP/core/XYZ.h>
 #include <IMP/core/rigid_bodies.h>
+#include <IMP/core/internal/dihedral_helpers.h>
 #include <cmath>
 
 IMPCORE_BEGIN_NAMESPACE
@@ -26,4 +27,10 @@ void transform(XYZ a, const algebra::Transformation3D &tr) {
   a.set_coordinates(tr.get_transformed(a.get_coordinates()));
 }
 
+double get_dihedral(XYZ a, XYZ b, XYZ c, XYZ d) {
+  return internal::dihedral(a.get_coordinates(), b.get_coordinates(),
+                            c.get_coordinates(), d.get_coordinates(), nullptr,
+                            nullptr, nullptr, nullptr);
+}
+
 IMPCORE_END_NAMESPACE
