@@ -86,6 +86,37 @@ class Tests(IMP.test.TestCase):
                 success = success + 1
         self.assertGreater(success, count / 2)
 
+    def test_get_members(self):
+        """Test rigid body get_member* functions"""
+        m = IMP.Model()
+        rb = IMP.core.RigidBody.setup_particle(IMP.Particle(m),
+                                               IMP.algebra.ReferenceFrame3D())
+        rigid_member = IMP.core.RigidMember.setup_particle(IMP.Particle(m))
+        non_rigid_member = IMP.core.NonRigidMember.setup_particle(
+                                                           IMP.Particle(m))
+        rigid_body = IMP.core.RigidBody.setup_particle(
+                     IMP.core.RigidMember.setup_particle(
+                           IMP.Particle(m)), IMP.algebra.ReferenceFrame3D())
+        non_rigid_body = IMP.core.RigidBody.setup_particle(
+                         IMP.core.NonRigidMember.setup_particle(
+                           IMP.Particle(m)), IMP.algebra.ReferenceFrame3D())
+        rb.add_member(rigid_member)
+        rb.add_non_rigid_member(non_rigid_member)
+        rb.add_member(rigid_body)
+        rb.add_non_rigid_member(non_rigid_body)
+        # Rigid members/bodies
+        self.assertEqual(rb.get_rigid_members(), [rigid_member, rigid_body])
+        # All members, rigid/nonrigid, member/body
+        self.assertEqual(rb.get_member_indexes(),
+                         IMP.get_indexes([rigid_member, non_rigid_member,
+                                          rigid_body, non_rigid_body]))
+        # Rigid/nonrigid members
+        self.assertEqual(rb.get_member_particle_indexes(),
+                         IMP.get_indexes([rigid_member, non_rigid_member]))
+        # Rigid/nonrigid bodies
+        self.assertEqual(rb.get_body_member_particle_indexes(),
+                         IMP.get_indexes([rigid_body, non_rigid_body]))
+
     def test_create_one_from_pdb(self):
         """Testing create_rigid_bodies"""
         m = IMP.kernel.Model()
