@@ -2,7 +2,7 @@
  *  \file writers.cpp
  *  \brief XXXX.
  *
- *  Copyright 2007-2013 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2014 IMP Inventors. All rights reserved.
  *
  */
 
@@ -10,8 +10,9 @@
 #include <IMP/display/internal/writers.h>
 
 IMPDISPLAY_BEGIN_INTERNAL_NAMESPACE
-std::map<std::string, WriterFactory *> &get_writer_factory_table() {
-  static std::map<std::string, WriterFactory *> table;
+std::map<std::string, boost::shared_ptr<WriterFactory> >&
+get_writer_factory_table() {
+  static std::map<std::string, boost::shared_ptr<WriterFactory> > table;
   return table;
 }
 
