@@ -28,11 +28,11 @@ class IMPEMEXPORT CoarseConvolution {
   //! Evaluates the convolution between two density grids
   /**
       f*g(n)=f(m)g(n-m); m runs between -inf to inf
-      \param[in] f A densityMap. note:
+      \param[in] f A DensityMap. note:
              correct RMSD and mean MUST be in the header!
       \param[in] g a sampled density map of particles
       \param[in] g_ps particles data (location, radii, weight)
-      \param[in] dvx vector to contain the xpartial derivatives for g_access_p
+      \param[in] dvx vector to contain the x partial derivatives for g_access_p
       \param[in] dvy vector to contain the y partial derivatives for g_access_p
       \param[in] dvz vector to contain the z partial derivatives for g_access_p
       \param[in] scalefactor scale factor to apply to the value of the cross
@@ -65,10 +65,10 @@ class IMPEMEXPORT CoarseConvolution {
       \param[in] voxel_data_threshold voxels with value lower than threshold
                  in model_map are not summed (avoid calculating correlation on
                  voxels below the threshold)
-      \param[in] recalc_ccnormfac Ignored. The purpose is to determines wheather
+      \param[in] recalc_ccnormfac Ignored. The purpose is to determines whether
                  the model_map should be
                  normalized prior to the correlation calculation. false is
-                 faster, but potentially innacurate
+                 faster, but potentially inaccurate
       \return the convolution value between two density maps
 
       \note recalc_ccnormfac is ignored.
