@@ -2,7 +2,7 @@
  *  \file IMP/em/DensityFillingRestraint.h
  *  \brief Score how well the particles fill the density
  *
- *  Copyright 2007-2013 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2014 IMP Inventors. All rights reserved.
  *
  */
 
@@ -25,9 +25,8 @@ IMPEM_BEGIN_NAMESPACE
 /** \ingroup exp_restraint
 
  */
-class IMPEMEXPORT DensityFillingRestraint : public kernel::Restraint
-{
-public:
+class IMPEMEXPORT DensityFillingRestraint : public kernel::Restraint {
+ public:
   //! Constructor
   /**
     \param[in] ps The particles participating in the fitting score
@@ -39,17 +38,17 @@ public:
     provide its members as input particles and not the rigid body.
     \todo we currently assume rigid bodies are also molecular hierarchies.
    */
-  DensityFillingRestraint(kernel::Particles ps,
-                               DensityMap *em_map,Float threshold);
+  DensityFillingRestraint(kernel::Particles ps, DensityMap *em_map,
+                          Float threshold);
 
-  virtual double
-  unprotected_evaluate(IMP::kernel::DerivativeAccumulator *accum)
-     const IMP_OVERRIDE;
+  virtual double unprotected_evaluate(IMP::kernel::DerivativeAccumulator *accum)
+      const IMP_OVERRIDE;
   virtual IMP::kernel::ModelObjectsTemp do_get_inputs() const IMP_OVERRIDE;
   IMP_OBJECT_METHODS(DensityFillingRestraint);
 
-  IMP_LIST(private, Particle, particle, kernel::Particle*, kernel::Particles);
-private:
+  IMP_LIST(private, Particle, particle, kernel::Particle *, kernel::Particles);
+
+ private:
   IMP::base::PointerMember<DensityMap> target_dens_map_;
   algebra::BoundingBoxD<3> target_bounding_box_;
   // reference to the IMP environment
