@@ -1,7 +1,7 @@
 /**
- *  \file em2d/ImageReaderWriter.h
+ *  \file IMP/em2d/ImageReaderWriter.h
  *  \brief Virtual class for reader/writers of images
- *  Copyright 2007-2013 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2014 IMP Inventors. All rights reserved.
 */
 
 #ifndef IMPEM2D_IMAGE_READER_WRITER_H
@@ -16,28 +16,25 @@
 IMPEM2D_BEGIN_NAMESPACE
 
 //! Virtual class for reader/writers of images
-class ImageReaderWriter : public IMP::base::Object
-{
-public:
-  ImageReaderWriter(): Object("ImageReaderWriter%1%"){}
-  virtual void read(const String &filename, em::ImageHeader& header,
+class ImageReaderWriter : public IMP::base::Object {
+ public:
+  ImageReaderWriter() : Object("ImageReaderWriter%1%") {}
+  virtual void read(const String &filename, em::ImageHeader &header,
                     cv::Mat &data) const = 0;
 
-  virtual void read_from_floats(const String &filename, em::ImageHeader& header,
+  virtual void read_from_floats(const String &filename, em::ImageHeader &header,
                                 cv::Mat &data) const = 0;
 
-  virtual void read_from_ints(const String &filename, em::ImageHeader& header,
+  virtual void read_from_ints(const String &filename, em::ImageHeader &header,
                               cv::Mat &data) const = 0;
 
-  virtual void write(const String &filename, em::ImageHeader& header,
+  virtual void write(const String &filename, em::ImageHeader &header,
                      const cv::Mat &data) const = 0;
 
-  virtual void write_to_floats(const String &filename,
-                               em::ImageHeader& header,
+  virtual void write_to_floats(const String &filename, em::ImageHeader &header,
                                const cv::Mat &data) const = 0;
 
-  virtual void write_to_ints(const String &filename,
-                             em::ImageHeader& header,
+  virtual void write_to_ints(const String &filename, em::ImageHeader &header,
                              const cv::Mat &data) const = 0;
 
   IMP_OBJECT_METHODS(ImageReaderWriter);
