@@ -1,8 +1,8 @@
 /**
- *  \file em2d/domino_filters.h
+ *  \file IMP/em2d/domino_filters.h
  *  \brief SubsetFilter for checking overlap between projections and images
  *
- *  Copyright 2007-2013 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2014 IMP Inventors. All rights reserved.
  *
  */
 
@@ -22,16 +22,15 @@
 IMPEM2D_BEGIN_NAMESPACE
 
 //! SubsetFilter for checking overlap between projections and images
-class IMPEM2DEXPORT DistanceFilter: public domino::SubsetFilter {
+class IMPEM2DEXPORT DistanceFilter : public domino::SubsetFilter {
 
-protected:
+ protected:
   domino::Subset subset_acting_on_;
   domino::Subset subset_restrained_;
   base::Pointer<domino::ParticleStatesTable> ps_table_;
   double max_distance_;
 
-public:
-
+ public:
   /*! Filter action on the distance between two particles. To be used with
       DOMINO
     \param[in] subset_to_act_on A subset that is going to be filtered.
@@ -44,22 +43,25 @@ public:
   */
   DistanceFilter(const domino::Subset &subset_to_act_on,
                  const domino::Subset &subset_to_restrain,
-                 domino::ParticleStatesTable *ps_table,
-                 double max_distance) : subset_acting_on_(subset_to_act_on),
-                                        subset_restrained_(subset_to_restrain),
-                                        ps_table_(ps_table),
-                                          max_distance_(max_distance) {
-    IMP_LOG_TERSE( "DistanceFilter created" << std::endl);
+                 domino::ParticleStatesTable *ps_table, double max_distance)
+      : subset_acting_on_(subset_to_act_on),
+        subset_restrained_(subset_to_restrain),
+        ps_table_(ps_table),
+        max_distance_(max_distance) {
+    IMP_LOG_TERSE("DistanceFilter created" << std::endl);
   }
   void show(std::ostream &out = std::cout) const {
     out << "DistanceFilter" << std::endl;
   }
-  IMP_SUBSET_FILTER(DistanceFilter);
+
+  virtual bool get_is_ok(const IMP::domino::Assignment &assignment) const
+        IMP_OVERRIDE;
+
+  IMP_OBJECT_NO_WARNING(DistanceFilter);
 };
 
-IMP_OBJECTS(DistanceFilter,DistanceFilters);
+IMP_OBJECTS(DistanceFilter, DistanceFilters);
 
 IMPEM2D_END_NAMESPACE
 
-
-#endif  /* IMPEM2D_DOMINO_FILTERS_H */
+#endif /* IMPEM2D_DOMINO_FILTERS_H */
