@@ -29,6 +29,20 @@
 
 IMPEM2D_BEGIN_NAMESPACE
 
+namespace {
+  class HasHigherCCCPointer
+  : public std::binary_function<RegistrationResult*, RegistrationResult*, bool>
+  {
+    HasHigherCCC<RegistrationResult> hhccc_;
+  public:
+    bool operator()(const RegistrationResult *a,
+                    const RegistrationResult *b) const {
+      return hhccc_(*a, *b);
+    }
+    void show(std::ostream &) const {}
+  };
+}
+
 void ProjectionFinder::set_subjects(const em2d::Images &subjects) {
   IMP_LOG_TERSE("ProjectionFinder: Setting subject images" << std::endl);
   if (subjects.size() == 0) {
@@ -52,7 +66,7 @@ void ProjectionFinder::set_subjects(const em2d::Images &subjects) {
   SUBJECTS_POLAR_AUTOC_.resize(n_subjects);
   subjects_cog_.resize(n_subjects);
   for (unsigned int i = 0; i < n_subjects; ++i) {
-    subjects_[i] = subjects[i];  // doest not deep copy
+    subjects_[i] = subjects[i];  // doesn't not deep copy
     std::ostringstream oss;
     oss << "Image subject " << i;
     subjects_[i]->set_name(oss.str());
@@ -67,7 +81,7 @@ void ProjectionFinder::set_variance_images(const em2d::Images &variances) {
   variances_.resize(variances.size());
   unsigned int n_variances = variances_.size();
   for (unsigned int i = 0; i < n_variances; ++i) {
-    variances_[i] = variances[i];  // doest not deep copy
+    variances_[i] = variances[i];  // doesn't not deep copy
 
     std::ostringstream oss;
     oss << "Variance subject " << i;
@@ -292,10 +306,11 @@ void ProjectionFinder::get_coarse_registration() {
     get_coarse_registrations_for_subject(i, coarse_RRs);
     coarse_registration_time_ += timer_coarse_subject.elapsed();
 
-    std::sort(coarse_RRs.begin(), coarse_RRs.end(),
+    RegistrationResults::iterator best_cc = std::min_element(
+              coarse_RRs.begin(), coarse_RRs.end(),
               HasHigherCCC<RegistrationResult>());
     // Best result after coarse registration is based on the ccc
-    registration_results_[i] = coarse_RRs[0];
+    registration_results_[i] = *best_cc;
     registration_results_[i].set_in_image(subjects_[i]->get_header());
     IMP_LOG_TERSE("Best coarse registration: " << registration_results_[i]
                                                << std::endl);
@@ -356,8 +371,16 @@ void ProjectionFinder::get_complete_registration() {
     get_coarse_registrations_for_subject(i, coarse_RRs);
     coarse_registration_time_ += timer_coarse_subject.elapsed();
     // The coarse registration scoring is done by cross-correlation
-    std::sort(coarse_RRs.begin(), coarse_RRs.end(),
-              HasHigherCCC<RegistrationResult>());
+
+    // Sort pointers to the original list; this should be slightly faster
+    // (no need to copy things around) but also works around a segfault
+    // (possible clang bug?) on OS X 10.10
+    std::vector<RegistrationResult*> sorted_coarse_RRs(coarse_RRs.size());
+    for (unsigned int k = 0; k < coarse_RRs.size(); ++k) {
+      sorted_coarse_RRs[k] = &coarse_RRs[k];
+    }
+    HasHigherCCCPointer hhccc;
+    std::sort(sorted_coarse_RRs.begin(), sorted_coarse_RRs.end(), hhccc);
 
     unsigned int n_optimized = projections_.size();
     if (fast_optimization_mode_) {
@@ -370,7 +393,7 @@ void ProjectionFinder::get_complete_registration() {
     boost::timer timer_fine_subject;
     for (unsigned int k = 0; k < n_optimized; ++k) {
       // Fine registration of the subject using simplex
-      coarse_RRs[k].set_in_image(subjects_[i]->get_header());
+      sorted_coarse_RRs[k]->set_in_image(subjects_[i]->get_header());
       IMP_LOG_TERSE(
           "Setting subject image to "
           "Fine2DRegistrationRestraint "
@@ -493,9 +516,9 @@ void ProjectionFinder::show(std::ostream &out) const {
       << "Working parameters: " << std::endl
       << "Resolution: " << params_.resolution << std::endl
       << "A/pixel: " << params_.pixel_size << std::endl
-      << "Coarse egistration method: " << params_.coarse_registration_method
+      << "Coarse registration method: " << params_.coarse_registration_method
       << std::endl << "Simplex initial size: " << params_.simplex_initial_length
-      << std::endl << "Simplex minimun size: " << params_.simplex_minimum_size
+      << std::endl << "Simplex minimum size: " << params_.simplex_minimum_size
       << std::endl
       << "Simplex maximum optimization steps: " << params_.optimization_steps
       << std::endl << "Save matching images: " << params_.save_match_images
