@@ -59,7 +59,7 @@ void do_histogram_stretching(cv::Mat &m, int boxes, int offset) {
   double max_val, min_val;
   cv::minMaxLoc(m, &min_val, &max_val);
   double maxmin = max_val - min_val;
-  // Histogram of boxes posible values
+  // Histogram of boxes possible values
   Ints hist(boxes, 0);
   for (cvDoubleMatIterator it = m.begin<double>(); it != m.end<double>();
        ++it) {
@@ -547,26 +547,13 @@ void do_resample_polar(const cv::Mat &input, cv::Mat &resampled,
 
 void do_normalize(cv::Mat &m) {
   cv::Scalar mean, stddev;
-  my_meanStdDev(m, mean, stddev);  // cv::meanStdDev(m,mean,stddev);
+  internal::my_meanStdDev(m, mean, stddev);
   IMP_LOG_VERBOSE("Matrix of mean: " << mean[0] << " stddev " << stddev[0]
                                      << " normalized. " << std::endl);
   m = m - mean[0];
   m = m / stddev[0];
 }
 
-void my_meanStdDev(const cv::Mat &m, cv::Scalar &mean, cv::Scalar &stddev) {
-  //#if CV_MAJOR_VERSION == 2 && CV_MINOR_VERSION < 4
-  //  cv::meanStdDev(m,mean,stddev);
-  //#endif
-  //#if CV_MAJOR_VERSION == 2 && CV_MINOR_VERSION > 3
-  mean = cv::mean(m);
-  cv::Mat square;
-  cv::pow(m - mean[0], 2, square);
-  cv::Scalar sum = cv::sum(square);
-  stddev[0] = std::sqrt(sum[0] / (m.rows * m.cols));
-  // #endif
-}
-
 //! Transform a matrix (the translation is interpreted as cols,rows)
 void get_transformed(const cv::Mat &input, cv::Mat &transformed,
                      const algebra::Transformation2D &T) {
