@@ -2,7 +2,7 @@
  *  \file QuasiNewton.cpp
  *  \brief XXXX.
  *
- *  Copyright 2007-2013 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2014 IMP Inventors. All rights reserved.
  *
  */
 
@@ -17,13 +17,6 @@ QuasiNewton::QuasiNewton(kernel::Model *m) : GSLOptimizer(m) {
   min_gradient_ = .001;
 }
 
-QuasiNewton::QuasiNewton() : GSLOptimizer() {
-  IMPGSL_DEPRECATED_FUNCTION_DEF(2.1, "Pass the model to the constructor.");
-  initial_step_ = .01;
-  line_step_ = .01;
-  min_gradient_ = .001;
-}
-
 Float QuasiNewton::do_optimize(unsigned int nsteps) {
   /* The GnuWin32 Windows build of GSL is only 1.8, which doesn't have bfgs2;
      use the older less efficient bfgs optimizer instead. */
@@ -31,7 +24,7 @@ Float QuasiNewton::do_optimize(unsigned int nsteps) {
 #if defined _MSC_VER
       = gsl_multimin_fdfminimizer_vector_bfgs;
 #else
-  = gsl_multimin_fdfminimizer_vector_bfgs2;
+      = gsl_multimin_fdfminimizer_vector_bfgs2;
 #endif
   return GSLOptimizer::optimize(nsteps, t, initial_step_, line_step_,
                                 min_gradient_);
