@@ -2,7 +2,7 @@
  *  \file IMP/isd/HybridMonteCarlo.h
  *  \brief A hybrid monte carlo implementation
  *
- *  Copyright 2007-2013 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2014 IMP Inventors. All rights reserved.
  *
  */
 
@@ -18,14 +18,13 @@
 IMPISD_BEGIN_NAMESPACE
 
 //! Hybrid Monte Carlo optimizer
-//moves all xyz particles having a fixed mass with an MD proposal
+// moves all xyz particles having a fixed mass with an MD proposal
 
-class IMPISDEXPORT HybridMonteCarlo : public core::MonteCarlo
-{
+class IMPISDEXPORT HybridMonteCarlo : public core::MonteCarlo {
 
-public:
-  HybridMonteCarlo(kernel::Model *m, Float kT=1.0, unsigned steps=100,
-          Float timestep=1.0, unsigned persistence=1);
+ public:
+  HybridMonteCarlo(kernel::Model *m, Float kT = 1.0, unsigned steps = 100,
+                   Float timestep = 1.0, unsigned persistence = 1);
 
   Float get_kinetic_energy() const;
 
@@ -33,35 +32,35 @@ public:
 
   Float get_total_energy() const;
 
-  //set md timestep
+  // set md timestep
   void set_timestep(Float ts);
   double get_timestep() const;
 
-  //set number of md steps per mc step
+  // set number of md steps per mc step
   void set_number_of_md_steps(unsigned nsteps);
   unsigned get_number_of_md_steps() const;
 
-  //set how many mc steps happen until you redraw the momenta
-  void set_persistence(unsigned persistence=1);
+  // set how many mc steps happen until you redraw the momenta
+  void set_persistence(unsigned persistence = 1);
   unsigned get_persistence() const;
 
-  //return pointer to isd::MolecularDynamics instance
-  //useful if you want to set other stuff that is not exposed here
-  MolecularDynamics* get_md() const;
+  // return pointer to isd::MolecularDynamics instance
+  // useful if you want to set other stuff that is not exposed here
+  MolecularDynamics *get_md() const;
 
-  //evaluate should return the total energy
+  // evaluate should return the total energy
   double do_evaluate(const kernel::ParticleIndexes &) const;
 
   virtual void do_step();
   IMP_OBJECT_METHODS(HybridMonteCarlo);
-private:
-  unsigned num_md_steps_,persistence_;
+
+ private:
+  unsigned num_md_steps_, persistence_;
   unsigned persistence_counter_;
   IMP::base::PointerMember<MolecularDynamicsMover> mv_;
   base::Pointer<MolecularDynamics> md_;
-
 };
 
 IMPISD_END_NAMESPACE
 
-#endif  /* IMPISD_HYBRID_MONTE_CARLO_H */
+#endif /* IMPISD_HYBRID_MONTE_CARLO_H */
