@@ -2,7 +2,7 @@
  *  \file IMP/kernel/generic.h    \brief Various important functionality
  *                                       for implementing decorators.
  *
- *  Copyright 2007-2013 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2014 IMP Inventors. All rights reserved.
  *
  */
 
@@ -11,6 +11,7 @@
 
 #include <IMP/kernel/kernel_config.h>
 #include "internal/scoring_functions.h"
+#include "internal/ContainerRestraint.h"
 #include "internal/TupleRestraint.h"
 #include "internal/TupleConstraint.h"
 
@@ -48,6 +49,12 @@ inline Restraint *create_restraint(const Score *s,
       IMP::kernel::internal::get_index(t), name);
 }
 
+template <class Score, class Container>
+inline Restraint *create_restraint(const Score *s, Container *t,
+                                   std::string name = std::string()) {
+  return internal::create_container_restraint(const_cast<Score *>(s), t, name);
+}
+
 /** When programming in C++, you can use generic constraint instead
     of a SingletonConstraint, PairConstraint, etc. The result is
     somewhat faster (20% or so).
