@@ -1,7 +1,7 @@
 /**
  *  \file Restraint.cpp   \brief Abstract base class for all restraints.
  *
- *  Copyright 2007-2013 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2014 IMP Inventors. All rights reserved.
  *
  */
 
@@ -14,34 +14,19 @@
 
 IMPKERNEL_BEGIN_NAMESPACE
 
-Container::Container(kernel::Model *m, std::string name) : ScoreState(m, name) {
+Container::Container(kernel::Model *m, std::string name)
+    : ModelObject(m, name) {
   IMP_USAGE_CHECK(m, "Must pass model to container constructor.");
-  // incremented to 0 at start
-  version_ = -1;
 #if IMP_HAS_CHECKS >= IMP_INTERNAL
   writeable_ = true;
   readable_ = true;
 #endif
 }
 
-void Container::set_is_changed(bool tf) {
-  validate_writable();
-  if (tf) {
-    ++version_;
-    if (version_ < 0) version_ = 0;
-  }
-}
-
-bool Container::get_is_changed() const {
-  IMPKERNEL_DEPRECATED_FUNCTION_DEF(2.1, "Use get_contents_version() instead.");
-  return true;
-}
-
-void Container::do_after_evaluate(DerivativeAccumulator *) {}
-
 void Container::validate_readable() const {
 #if IMP_HAS_CHECKS >= IMP_INTERNAL
   if (!readable_) {
+    base::handle_error("bad container read");
     throw internal::InputOutputException(get_name(),
                                          internal::InputOutputException::GET);
   }
@@ -50,6 +35,7 @@ void Container::validate_readable() const {
 void Container::validate_writable() const {
 #if IMP_HAS_CHECKS >= IMP_INTERNAL
   if (!writeable_) {
+    base::handle_error("bad container written");
     throw internal::InputOutputException(get_name(),
                                          internal::InputOutputException::GET);
   }
