@@ -120,35 +120,32 @@ class IMPKMEANSEXPORT KMeans : public IMP::base::Object {
   */
   void add_data_pt(const IMP::Floats& p);
 
-  /**
-     Clears all data in object.
-  */
+  //! Clears all data in object.
   void clear_data();
 
-  /** Returns the i'th point in the dataset
-
+  //! Returns the i'th point in the dataset
+  /**
       @param[in] i Center number in range (0,...,nPts-1)
    */
   const IMP::Floats& get_data_point(unsigned int i) const;
 
-  /** @return The number of data points */
+  //! @return The number of data points
   unsigned int get_number_of_data_points() const { return STLDataPts_.size(); }
 
+  //! Print the centers (assuming execute() was applied) to log
   /**
-      Print the centers (assuming exectute() was applied) to log
-
       @param ll the log level for printout
    */
   void print_centers(base::LogLevel ll = base::PROGRESS) const;
 
-  /** Returns the i'th center
-      Must be called only following a succesful execute() invokation
+  //! Returns the i'th center
+  /** Must be called only following a successful execute() invocation
 
       @param[in] i Center number in range (0,...,k-1)
    */
   IMP::Floats get_center(unsigned int i) const;
 
-  /** Returns the cluster assignment of each data point */
+  //! Returns the cluster assignment of each data point
   IMP::Ints get_assignments() const {
     // TODO: exception instead of assertion?
     assert(is_executed_);
@@ -163,7 +160,7 @@ class IMPKMEANSEXPORT KMeans : public IMP::base::Object {
     return ptsSqrDistToCenters_;
   }
 
-  /** @return The number of centers after a succeful execution */
+  /** @return The number of centers after a successful execution */
   unsigned int get_number_of_centers() const {
     assert(is_executed_);  // TODO: exception?
     return pCenters_->getK();
@@ -218,13 +215,13 @@ class IMPKMEANSEXPORT KMeans : public IMP::base::Object {
 
   /*********************** Private Variables **************************/
  private:
-  // was k-means executed succesfully
+  // was k-means executed successfully
   bool is_executed_;
 
   // The data points in STL format
   IMP::FloatsList STLDataPts_;
 
-  // data points in wrapped internal::KMdata strcture
+  // data points in wrapped internal::KMdata structure
   // (should be synced from STLDataPts_ before usage)
   base::Pointer<internal::KMdata> pKMDataPts_;
 
