@@ -2,7 +2,7 @@
  *  \file IMP/multifit/anchor_utilities.h
  *  \brief Common functions in anchor calculations
  *
- *  Copyright 2007-2013 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2014 IMP Inventors. All rights reserved.
  *
  */
 
@@ -19,25 +19,21 @@
 IMPMULTIFIT_BEGIN_NAMESPACE
 
 IMPMULTIFITEXPORT
-inline AnchorsData molecule2anchors(atom::Hierarchy mh,int k) {
-  IMP_NEW(IMP::statistics::internal::ParticlesDataPoints,ddp,
+inline AnchorsData molecule2anchors(atom::Hierarchy mh, int k) {
+  IMP_NEW(IMP::statistics::internal::ParticlesDataPoints, ddp,
           (core::get_leaves(mh)));
-  IMP::statistics::internal::VQClustering vq(ddp,k);
+  IMP::statistics::internal::VQClustering vq(ddp, k);
   vq.run();
-  multifit::DataPointsAssignment assignment(ddp,&vq);
-  multifit::AnchorsData ad(
-                          assignment.get_centers(),
-                          *(assignment.get_edges()));
+  multifit::DataPointsAssignment assignment(ddp, &vq);
+  multifit::AnchorsData ad(assignment.get_centers(), *(assignment.get_edges()));
   return ad;
 }
 
 IMPMULTIFITEXPORT
 //! Generate anchors in several formats for a given density map.
 void get_anchors_for_density(em::DensityMap *dmap, int number_of_means,
-                             float density_threshold,
-                             std::string pdb_filename,
-                             std::string cmm_filename,
-                             std::string seg_filename,
+                             float density_threshold, std::string pdb_filename,
+                             std::string cmm_filename, std::string seg_filename,
                              std::string txt_filename);
 
 //! Get lists of anchors that match a sequence of secondary structures
@@ -49,9 +45,8 @@ void get_anchors_for_density(em::DensityMap *dmap, int number_of_means,
 */
 IMPMULTIFITEXPORT
 IntsList get_anchor_indices_matching_secondary_structure(
-                                  const AnchorsData &ad,
-                                  const atom::SecondaryStructureResidues &ssrs,
-                                  Float max_rmsd=0.7);
+    const AnchorsData &ad, const atom::SecondaryStructureResidues &ssrs,
+    Float max_rmsd = 0.7);
 
 IMPMULTIFIT_END_NAMESPACE
 
