@@ -2,7 +2,7 @@
  *  \file IMP/multifit/coarse_molecule.h
  *  \brief coarsen molecule by clustering
  *
- *  Copyright 2007-2013 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2014 IMP Inventors. All rights reserved.
  *
  */
 
@@ -26,10 +26,8 @@ IMPMULTIFIT_BEGIN_NAMESPACE
  */
 IMPMULTIFITEXPORT
 atom::Hierarchy create_coarse_molecule_from_molecule(
-         const atom::Hierarchy &mh,int num_beads,
-         kernel::Model *mdl,
-         float bead_radius,
-         bool add_conn_restraint = false);
+    const atom::Hierarchy &mh, int num_beads, kernel::Model *mdl,
+    float bead_radius, bool add_conn_restraint = false);
 
 //! Coarsen molecules based on atom clustering
 /**
@@ -43,11 +41,8 @@ atom::Hierarchy create_coarse_molecule_from_molecule(
  */
 IMPMULTIFITEXPORT
 atom::Hierarchies create_coarse_molecules_from_molecules(
-                  const atom::Hierarchies &mhs,
-                  int frag_len,
-                  kernel::Model *mdl,
-                  float bead_radius,
-                  bool add_conn_restraint = false);
+    const atom::Hierarchies &mhs, int frag_len, kernel::Model *mdl,
+    float bead_radius, bool add_conn_restraint = false);
 
 //! Coarsen a density map based on voxels clustering
 /**
@@ -59,13 +54,12 @@ atom::Hierarchies create_coarse_molecules_from_molecules(
 \param[in] bead_radius bead radius
  */
 IMPMULTIFITEXPORT
-atom::Hierarchy create_coarse_molecule_from_density(
-    em::DensityMap *dmap,
-    float dens_threshold,
-    int num_beads,
-    kernel::Model *mdl,
-    float bead_radius);
+atom::Hierarchy create_coarse_molecule_from_density(em::DensityMap *dmap,
+                                                    float dens_threshold,
+                                                    int num_beads,
+                                                    kernel::Model *mdl,
+                                                    float bead_radius);
 
 IMPMULTIFIT_END_NAMESPACE
 
-#endif  /* IMPMULTIFIT_COARSE_MOLECULE_H */
+#endif /* IMPMULTIFIT_COARSE_MOLECULE_H */
