@@ -18,26 +18,41 @@ try:
     # module needs: http://bugs.winehq.org/show_bug.cgi?id=17273
     if sys.platform == 'win32' and 'WINELOADERNOEXEC' in os.environ:
         multiproc_exception = "Wine does not currently support multiprocessing"
-except ImportError, detail:
+except ImportError as detail:
     multiproc_exception = str(detail)
 
+
 class Fitter(object):
-    def __init__(self, em_map, spacing, resolution, origin, density_threshold,pdb, fits_fn, angle,num_fits,angles_per_voxel,ref_pdb=''):
+
+    def __init__(
+        self,
+        em_map,
+        spacing,
+        resolution,
+        origin,
+        density_threshold,
+        pdb,
+        fits_fn,
+        angle,
+        num_fits,
+        angles_per_voxel,
+            ref_pdb=''):
         self.em_map = em_map
         self.spacing = spacing
         self.resolution = resolution
-        self.threshold=density_threshold
+        self.threshold = density_threshold
         self.originx = origin[0]
         self.originy = origin[1]
         self.originz = origin[2]
         self.pdb = pdb
         self.fits_fn = fits_fn
         self.angle = angle
-        self.num_fits=num_fits
-        self.angles_per_voxel=angles_per_voxel
-        self.ref_pdb=ref_pdb
+        self.num_fits = num_fits
+        self.angles_per_voxel = angles_per_voxel
+        self.ref_pdb = ref_pdb
+
     def run(self):
-        print "resolution is:",self.resolution
+        print "resolution is:", self.resolution
         dmap = IMP.em.read_map(self.em_map)
         dmap.get_header().set_resolution(self.resolution)
         dmap.update_voxel_size(self.spacing)
@@ -48,38 +63,40 @@ class Fitter(object):
         dmap.get_header().show()
         mdl = IMP.kernel.Model()
         mol2fit = IMP.atom.read_pdb(self.pdb, mdl)
-        mh_xyz=IMP.core.XYZs(IMP.core.get_leaves(mol2fit))
+        mh_xyz = IMP.core.XYZs(IMP.core.get_leaves(mol2fit))
         rb = IMP.atom.create_rigid_body(mol2fit)
         ff = IMP.multifit.FFTFitting()
         ff.set_was_used(True)
-        fits = ff.do_global_fitting(dmap, self.threshold,mol2fit,
+        fits = ff.do_global_fitting(dmap, self.threshold, mol2fit,
                                     self.angle / 180.0 * math.pi,
                                     self.num_fits, self.spacing, 0.5,
                                     True, self.angles_per_voxel)
         fits.set_was_used(True)
         final_fits = fits.best_fits_
-        if self.ref_pdb!='':
-            ref_mh=IMP.atom.read_pdb(self.ref_pdb,mdl)
-            ref_mh_xyz=IMP.core.XYZs(IMP.core.get_leaves(ref_mh))
-            cur_low=[1e4,0]
+        if self.ref_pdb != '':
+            ref_mh = IMP.atom.read_pdb(self.ref_pdb, mdl)
+            ref_mh_xyz = IMP.core.XYZs(IMP.core.get_leaves(ref_mh))
+            cur_low = [1e4, 0]
         for i, fit in enumerate(final_fits):
             fit.set_index(i)
-            if self.ref_pdb!='':
-                trans=fit.get_fit_transformation()
-                IMP.atom.transform(mol2fit,trans)
-                rmsd=IMP.atom.get_rmsd(mh_xyz,ref_mh_xyz)
-                if rmsd<cur_low[0]:
-                    cur_low[0]=rmsd
-                    cur_low[1]=i
+            if self.ref_pdb != '':
+                trans = fit.get_fit_transformation()
+                IMP.atom.transform(mol2fit, trans)
+                rmsd = IMP.atom.get_rmsd(mh_xyz, ref_mh_xyz)
+                if rmsd < cur_low[0]:
+                    cur_low[0] = rmsd
+                    cur_low[1] = i
                 fit.set_rmsd_to_reference(rmsd)
-                IMP.atom.transform(mol2fit,trans.get_inverse())
-        if self.ref_pdb!='':
-            print 'from all fits, lowest rmsd to ref:',cur_low
+                IMP.atom.transform(mol2fit, trans.get_inverse())
+        if self.ref_pdb != '':
+            print 'from all fits, lowest rmsd to ref:', cur_low
         IMP.multifit.write_fitting_solutions(self.fits_fn, final_fits)
 
+
 def do_work(f):
     f.run()
 
+
 def parse_args():
     usage = """%prog [options] <assembly input>
 
@@ -102,7 +119,7 @@ Fit subunits into a density map with FFT."""
                       help="Number of angles to keep per voxel"
                            "(default 10)")
 
-    #parser.add_option("-n", "--num", dest="num", type="int",
+    # parser.add_option("-n", "--num", dest="num", type="int",
     #                  default=100,
     #                  help="Number of fits to report"
     #                      "(default 100)")
@@ -110,21 +127,32 @@ Fit subunits into a density map with FFT."""
     options, args = parser.parse_args()
     if len(args) != 1:
         parser.error("incorrect number of arguments")
-    return options,args
+    return options, args
+
 
 def run(asmb_fn, options):
     if multiproc_exception is None and options.cpus > 1:
         work_units = []
-    asmb_input=IMP.multifit.read_settings(asmb_fn)
+    asmb_input = IMP.multifit.read_settings(asmb_fn)
     asmb_input.set_was_used(True)
-    em_map=asmb_input.get_assembly_header().get_dens_fn()
-    resolution=asmb_input.get_assembly_header().get_resolution()
-    spacing=asmb_input.get_assembly_header().get_spacing()
-    origin=asmb_input.get_assembly_header().get_origin()
+    em_map = asmb_input.get_assembly_header().get_dens_fn()
+    resolution = asmb_input.get_assembly_header().get_resolution()
+    spacing = asmb_input.get_assembly_header().get_spacing()
+    origin = asmb_input.get_assembly_header().get_origin()
     for i in range(asmb_input.get_number_of_component_headers()):
-        fits_fn=asmb_input.get_component_header(i).get_transformations_fn()
-        pdb_fn=asmb_input.get_component_header(i).get_filename()
-        f = Fitter(em_map, spacing, resolution, origin, asmb_input.get_assembly_header().get_threshold(),pdb_fn, fits_fn, options.angle,options.num,options.angle_voxel)
+        fits_fn = asmb_input.get_component_header(i).get_transformations_fn()
+        pdb_fn = asmb_input.get_component_header(i).get_filename()
+        f = Fitter(
+            em_map,
+            spacing,
+            resolution,
+            origin,
+            asmb_input.get_assembly_header().get_threshold(),
+            pdb_fn,
+            fits_fn,
+            options.angle,
+            options.num,
+            options.angle_voxel)
         if multiproc_exception is None and options.cpus > 1:
             work_units.append(f)
         else:
@@ -142,10 +170,11 @@ Running on a single processor.""" % multiproc_exception
         p = Pool(processes=nproc)
         out = list(p.imap_unordered(do_work, work_units))
 
+
 def main():
-    options,args = parse_args()
+    options, args = parse_args()
     asmb_input = args[0]
     run(asmb_input, options)
 
-if __name__=="__main__":
+if __name__ == "__main__":
     main()
