@@ -17,12 +17,16 @@
 IMPRMF_BEGIN_INTERNAL_NAMESPACE
 
 class IMPRMFEXPORT HierarchyLoadXYZs {
+  RMF::decorator::ReferenceFrameFactory reference_frame_factory_;
   RMF::decorator::IntermediateParticleFactory ip_factory_;
   typedef std::pair<RMF::NodeID, kernel::ParticleIndex> Pair;
   typedef base::Vector<Pair> NodeParticlePairs;
 
   NodeParticlePairs global_, local_;
 
+  // backwards compat
+  RMF::IntKey rb_index_key_;
+
  public:
   HierarchyLoadXYZs(RMF::FileConstHandle f);
   void setup_particle(RMF::NodeConstHandle n, kernel::Model *m,
