@@ -68,6 +68,9 @@ void HierarchyLoadRigidBodies::setup_particle(
       core::RigidBody::setup_particle(m, pi, algebra::ReferenceFrame3D());
     }
     core::RigidBody arb(m, rigid_body_compositions_.find(rb)->second.rb);
+    // set dummy coordinates (add_member() will try to use them)
+    if (!core::XYZ::get_is_setup(m, p)) core::XYZ::setup_particle(m, p);
+    core::XYZ(m, p).set_coordinates(algebra::Vector3D(0., 0., 0.));
     if (!ip_factory_.get_is_static(n)) {
       arb.add_non_rigid_member(p);
     } else {
@@ -99,7 +102,9 @@ kernel::ParticleIndex HierarchyLoadRigidBodies::find_rigid_body(
 void HierarchyLoadRigidBodies::link_rigid_body(
     RMF::NodeConstHandle n, kernel::Model *m, kernel::ParticleIndex p,
     kernel::ParticleIndexes &rigid_bodies) {
-  if (reference_frame_factory_.get_is_static(n)) {
+  // Cannot use reference_frame_factory_ here because for nonrigid nested
+  // rigid body members no static values are set in RMF
+  if (core::RigidMember::get_is_setup(m, p)) {
     IMP_LOG_VERBOSE("Rigid body " << m->get_particle_name(p) << " is static"
                                   << std::endl);
   } else if (rigid_bodies.empty()) {
@@ -117,7 +122,8 @@ void HierarchyLoadRigidBodies::link_particle(
     kernel::ParticleIndex rb = find_rigid_body(m, p);
     link_rigid_body(n, m, rb, rigid_bodies);
   } else {
-    if (reference_frame_factory_.get_is(n)) {
+    if (core::RigidBody::get_is_setup(m, p)
+        || reference_frame_factory_.get_is(n)) {
       link_rigid_body(n, m, p, rigid_bodies);
     }
 
@@ -136,7 +142,7 @@ void HierarchyLoadRigidBodies::fix_internal_coordinates(
     core::RigidBody, algebra::ReferenceFrame3D rf,
     core::RigidBodyMember rm) const {
   // Make sure the internal coordinates of the particles match
-  // This is needed to handle scripts that change them during optimation
+  // This is needed to handle scripts that change them during optimization
   // and save the result out to RMF.
   if (core::RigidBody::get_is_setup(rm)) {
     core::RigidBody crb(rm);
@@ -161,8 +167,11 @@ void HierarchyLoadRigidBodies::fix_rigid_body(Model *m, const RB &in) const {
       rigid_bits.push_back(pi);
     }
   }
-  IMP_USAGE_CHECK(!rigid_bits.empty(), "No rigid particles to align rigid"
-                                           << " body with");
+  if (rigid_bits.empty()) {
+    // all members are non-rigid, so nothing to do
+    return;
+  }
+
   rb.set_reference_frame_from_members(rigid_bits);
   algebra::ReferenceFrame3D rf = rb.get_reference_frame();
   // fix rigid bodies that aren't rigid
@@ -210,7 +219,7 @@ void HierarchyLoadRigidBodies::load(RMF::FileConstHandle fh, Model *m) {
                     << m->get_particle_name(pp.second) << std::endl);
     algebra::ReferenceFrame3D rf(
         get_transformation(fh.get_node(pp.first), reference_frame_factory_));
-    core::RigidBody(m, pp.second).set_reference_frame(rf);
+    core::RigidBody(m, pp.second).set_reference_frame_lazy(rf);
   }
   IMP_FOREACH(Pair pp, local_) {
     IMP_LOG_VERBOSE("Loading local rigid body "
@@ -220,6 +229,11 @@ void HierarchyLoadRigidBodies::load(RMF::FileConstHandle fh, Model *m) {
     core::RigidBodyMember(m, pp.second)
         .set_internal_transformation(rf.get_transformation_to());
   }
+  /* Make sure that the global coordinates of any nested rigid bodies are
+     set from their parents */
+  IMP_FOREACH(Pair pp, global_) {
+    core::RigidBody(m, pp.second).update_members();
+  }
 }
 
 void HierarchyLoadRigidBodies::update_rigid_bodies(RMF::FileConstHandle,
@@ -321,7 +335,7 @@ void HierarchySaveRigidBodies::save(kernel::Model *m, RMF::FileHandle fh) {
   }
   IMP_FOREACH(Pair pp, local_) {
     copy_to_frame_reference_frame(
-        core::RigidMember(m, pp.second).get_internal_transformation(),
+        core::RigidBodyMember(m, pp.second).get_internal_transformation(),
         fh.get_node(pp.first), reference_frame_factory_);
   }
 }
