@@ -32,6 +32,8 @@ class Harmonic : public Score {
       double distance) const {
     return DerivativePair(get_score(m, p, distance), k_ * (distance));
   }
+  double get_k() { return k_; }
+  void set_k(double k) { k_ = k; }
 };
 
 IMPSCOREFUNCTOR_END_NAMESPACE
