@@ -1,12 +1,12 @@
 /**
  *  \file Clustering.cpp   \brief Holds data points to cluster using k-means
  *
- *  Copyright 2007-2013 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2014 IMP Inventors. All rights reserved.
  *
  */
 #include <IMP/statistics/PartitionalClustering.h>
 #include <IMP/base/check_macros.h>
-#include <IMP/base/set.h>
+#include <boost/unordered_set.hpp>
 
 IMPSTATISTICS_BEGIN_NAMESPACE
 PartitionalClustering::~PartitionalClustering() {}
@@ -16,7 +16,7 @@ void validate_partitional_clustering(PartitionalClustering* pc,
   IMP_CHECK_VARIABLE(pc);
   IMP_CHECK_VARIABLE(n);
   IMP_IF_CHECK(base::USAGE) {
-    IMP::base::set<int> used;
+    boost::unordered_set<int> used;
     for (unsigned int i = 0; i < pc->get_number_of_clusters(); ++i) {
       Ints cluster = pc->get_cluster(i);
       for (unsigned int j = 0; j < cluster.size(); ++j) {
