@@ -156,7 +156,7 @@ if [ "${TARGET_OSX_VER}" = "10.6" ]; then
                 /usr/local/lib/libjpeg.8.dylib \
                 /usr/local/lib/libtiff.5.dylib \
                 /usr/local/lib/liblzma.5.dylib \
-                /usr/local/lib/libprotobuf.8.dylib \
+                /usr/local/lib/libprotobuf.9.dylib \
                 /usr/local/lib/libTAU.1.dylib \
                 /usr/local/lib/libCGAL.10.0.3.dylib \
                 /usr/local/lib/libCGAL.10.dylib \
@@ -281,7 +281,7 @@ mkdir imp-${VER}-package || exit 1
        -d Description.plist.$$ -ds \
        -p "imp-${VER}-package/IMP ${VER} ${TARGET_OSX_VER}.pkg" -f ${DESTDIR} \
        || exit 1
-cp ${MAC_TOOL_DIR}/README.txt imp-${VER}-package || exit 1
+cp ${MAC_TOOL_DIR}/pkg-README.txt imp-${VER}-package/README.txt || exit 1
 rm -f Info.plist.$$ Description.plist.$$
 
 echo "Making disk image (.dmg)..."
